@@ -1,7 +1,7 @@
 plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0, 
     interc=TRUE, link = TRUE, res.col = 1, rev.sgn = FALSE, const = 0, 
     shade=FALSE, rug=TRUE, dens.rug=FALSE, dens.col = grey(0.8),
-    show.gap=FALSE, transf=I, ...){
+    transf=I, ...){
 #funzione plot.segmented che consente di disegnare anche i pointwise CI
         f.U<-function(nomiU, term=NULL){
         #trasforma i nomi dei coeff U (o V) nei nomi delle variabili corrispondenti
@@ -26,7 +26,9 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
         }
 #--------------
   #se l'oggetto e' segmented.Arima il nome dell'eventuale interc va sostituito..
-  if((all(class(x)==c("segmented", "Arima")))) names(x$coef)<-gsub("intercept", "(Intercept)", names(coef(x)))
+#  if((all(class(x)==c("segmented", "Arima")))) names(x$coef)<-gsub("intercept", "(Intercept)", names(coef(x)))
+  if(all(c("segmented", "Arima") %in% class(x))) names(x$coef)<-gsub("intercept", "(Intercept)", names(coef(x)))
+
 #--------------
     linkinv <- !link
     if (inherits(x, what = "glm", which = FALSE) && linkinv && !is.null(x$offset) && res) stop("residuals with offset on the response scale?")
@@ -42,10 +44,10 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
         else {
             term <- x$nameUV$Z
         }
-    }
-    else {
-        if (!term %in% x$nameUV$Z)
-            stop("invalid `term'")
+    } else {
+        dterm<- deparse(substitute(term))
+        if(dterm %in% x$nameUV$Z) term<-dterm
+        if (! isTRUE(term %in% x$nameUV$Z)) stop("invalid `term'")
     }
     opz <- list(...)
     cols <- opz$col
@@ -69,7 +71,8 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
     ylabs <- opz$ylab
     if (length(ylabs) <= 0)
         ylabs <- paste("Effect  of ", term, sep = " ")
-    a <- intercept(x, term, gap = show.gap)[[1]][, "Est."]
+    #a <- intercept(x, term, gap = show.gap)[[1]][, "Est."]
+    a <- intercept(x, term)[[1]][, "Est."]
     #Poiche' intercept() restituisce quantita' che includono sempre l'intercetta del modello, questa va eliminata se interc=FALSE
     if(!interc && ("(Intercept)" %in% names(coef(x)))) a<- a-coef(x)["(Intercept)"]
     b <- slope(x, term)[[1]][, "Est."]
@@ -85,14 +88,17 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
     n<-length(x$residuals) #fitted.values - Arima non ha "fitted.values", ma ha "residuals"..
     tipo<- if(inherits(x, what = "glm", which = FALSE) && link) "link" else "response"
     
-    vall<-sort(c(seq(min(val), max(val), l=120), est.psi))
+    vall<-sort(c(seq(min(val), max(val), l=150), est.psi))
     #ciValues<-predict.segmented(x, newdata=vall, se.fit=TRUE, type=tipo, level=conf.level)
     vall.list<-list(vall)
     names(vall.list)<-term
-    ciValues<-broken.line(x, vall.list, link=link, interc=interc, se.fit=TRUE)
+    
     
     if(conf.level>0) {
-        k.alpha<-if(inherits(x, what = c("glm","Arima"), which = FALSE)) abs(qnorm((1-conf.level)/2)) else abs(qt((1-conf.level)/2, x$df.residual))
+        #k.alpha<-if(inherits(x, what = c("glm","Arima"), which = FALSE)) abs(qnorm((1-conf.level)/2)) else abs(qt((1-conf.level)/2, x$df.residual))
+        #cambiato nella 0.5-2.0:
+        k.alpha<-if(inherits(x, what = "lm", which = FALSE)) abs(qt((1-conf.level)/2, x$df.residual)) else abs(qnorm((1-conf.level)/2)) 
+        ciValues<-broken.line(x, vall.list, link=link, interc=interc, se.fit=TRUE)
         ciValues<-cbind(ciValues$fit, ciValues$fit- k.alpha*ciValues$se.fit, ciValues$fit + k.alpha*ciValues$se.fit)
         #---> transf...
         ciValues<-apply(ciValues, 2, transf)
@@ -109,7 +115,9 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
     b.ok1 <- c(b, b[length(b)])
     y.val <- y.val1 <- a.ok1 + b.ok1 * val + const
     s <- 1:(length(val) - 1)
-    xvalues <- if(all(class(x)==c("segmented", "Arima"))) x$Z[,1] else  x$model[, term]
+#    xvalues <- if(all(class(x)==c("segmented", "Arima"))) x$Z[,1] else  x$model[, term]
+    xvalues <-  if(all(c("segmented", "Arima") %in% class(x))) x$Z[,1] else  x$model[, term]
+
     if (rev.sgn) {
         val <- -val
         xvalues <- -xvalues
@@ -128,7 +136,8 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
             #broken.line(x, term, gap = show.gap, link = link) + resid(x, "response") + const
               fit0 + resid(x, "response") + const        
                 else x$family$linkinv(c(y.val, y.val1))
-        xout <- sort(c(seq(val[1], val[length(val)], l = 120), val[-c(1, length(val))]))
+#        xout <- sort(c(seq(val[1], val[length(val)], l = 150), val[-c(1, length(val))]))
+        xout <- sort(c(seq(val[1], val[length(val)], l = 150), val[-c(1, length(val))],val[-c(1, length(val))]*1.005))
         l <- approx(as.vector(m[, c(1, 3)]), as.vector(m[, c(2, 4)]), xout = xout)
         id.group <- cut(l$x, val, FALSE, TRUE)
         yhat <- l$y
